================================
openstack/networking-zvm Project
================================

About this project
------------------

This project provides the OpenStack Neutron mechanism driver and L2 agent for
the z/VM of IBM z Systems and IBM LinuxOne machines.

z/VM provides a highly secure and scalable enterprise cloud infrastructure
and an environment for efficiently running multiple diverse critical
applications on IBM z Systems and IBM LinuxONE with support for more virtual
servers than any other platform in a single footprint.
These z/VM virtual servers can run Linux, z/OS and more. 

For more information, please refer to http://www.vm.ibm.com/

Links
-----

* Documentation: `<http://networking-zvm.readthedocs.io/en/latest/>`_
* Source: `<http://git.openstack.org/cgit/openstack/networking-zvm>`_
* Github shadow: `<https://github.com/openstack/networking-zvm>`_
* Bugs: `<http://bugs.launchpad.net/networking-zvm>`_
* Gerrit: `<https://review.openstack.org/#/q/project:openstack/networking-zvm>`_
* License: Apache 2.0 license
